# -*- coding: iso-8859-1 -*-
# vim: set ft=python ts=3 sw=3 expandtab:
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
#              C E D A R
#          S O L U T I O N S       "Software done right."
#           S O F T W A R E
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Author   : Kenneth J. Pronovici <pronovic@ieee.org>
# Language : Python (>= 2.3)
# Project  : WordUtils
# Revision : $Id: release.py,v 1.1 2003/07/16 05:23:04 pronovic Exp $
# Purpose  : Provides location to maintain version information.
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

"""
Provides location to maintain version information.

@sort: AUTHOR, EMAIL, COPYRIGHT, VERSION, DATE, URL

@var AUTHOR: Author of software.
@var EMAIL: Email address of author.
@var COPYRIGHT: Copyright date.
@var VERSION: Software version.
@var DATE: Software release date.
@var URL: URL of WordUtils webpage.

@author: Kenneth J. Pronovici <pronovic@ieee.org>
"""

AUTHOR      = "Kenneth J. Pronovici"
EMAIL       = "pronovic@ieee.org"
COPYRIGHT   = "2003-2005"
VERSION     = "0.8.0"
DATE        = "27 Sep 2005"
URL         = "http://www.cedar-solutions.com/software/wordutils/"

